[svn.haxx.se] · SVN Dev · SVN Users · SVN Org · TSVN Dev · TSVN Users · Subclipse Dev · Subclipse Users · this month's index

Re: NCR MPRAS SVR4 port of SVN Client

From: Andrew Cilia <acilia_at_ptl.com.mt>
Date: 2005-11-21 10:20:15 CET

Hi Erik,
    do you mind if I pass the unidiff on to you so I don't have to get
into another mailing list? I wish I could participate more in the
project but pressures at work prohibit me from doing so. I hope this is
not an imposition.

Thanks

On Wed, 2005-11-09 at 00:15 +0100, Erik Huelsmann wrote:
> On 11/8/05, Andrew Cilia <acilia@ptl.com.mt> wrote:
> > Hi,
> > I have a number of oldish NCR MPRAS development servers that I wanted
> > to make part of the ongoing SVN effort of our company. I found that the
> > only thing that stopped me from doing so was the name of a typedef in
> > subversion/libsvn_ra_dav/commit.c. Apparently resource_t is a typedef in
> > the systems mplock.h file and thus there was a clash. If you carry out
> > the following changes, we can say that we have another OS on board. I
> > wish to point out that my efforts thus far have been to make the client
> > work as I am not interested in running an svn server on this machine.
> > Should I have the time, I will attempt to download and compile db4 and
> > re-make everything. The patch (based on version 1.2.3) is as follows:
> >
> > 54c54
> > < ** resource_t: identify the relevant pieces of a resource on the
>
> Hi Andrew!
>
> Thanks for the report!
>
> Could you please submit your changes to dev@subversion.tigris.org and
> supply the diff in unidiff format?
>
> Thanks!
>
> I've committed something quite similar to what you provided in r17262,
> which will be incorporated in 1.4.
>
>
> bye,
>
>
> Erik.

-- 
Andrew Cilia B.Sc. RHCE MCSE ICSE
Senior Software Consultant
Philip Toledo Limited
Computer & Communications Solutions
Notabile Road, Mriehel BKR01, Malta
Tel: (+356) 2144 5566
Mobile: (+356) 9943 0588
Fax: (+356) 2148 4316
Website : www.ptl.com.mt
The information contained in this email is confidential and may be privileged. 
It is intended for the addressee only, if you are not the intended recipient 
please notify the sender and delete the email immediately. The contents of 
this e-mail must not be disclosed or copied without the senders consent. We 
cannot accept any responsibility for viruses. Any views expressed in this 
message are those of the individual sender, except where the sender 
specifically states them to be the view of Philip Toledo Limited

--- commit.orig 2005-11-21 10:14:32.000000000 +0100
+++ commit.c 2005-11-21 10:14:29.000000000 +0100
@@ -51,7 +51,7 @@
 
 
 /*
** resource_t: identify the relevant pieces of a resource on the server
 **
 ** REVISION is the resource's revision, or SVN_INVALID_REVNUM if it is
 ** new or is the HEAD.
@@ -75,7 +75,7 @@
   const char *local_path;
   apr_pool_t *pool; /* pool in which this resource is allocated. */
 
-} resource_t;
+} resauce_t;
 
 
 /* Context for parsing <D:error> bodies, used when we call ne_copy(). */
@@ -138,7 +138,7 @@
 typedef struct
 {
   commit_ctx_t *cc;
- resource_t *rsrc;
+ resauce_t *rsrc;
   apr_hash_t *prop_changes; /* name/values pairs of new/changed properties. */
   apr_array_header_t *prop_deletes; /* names of properties to delete. */
   svn_boolean_t created; /* set if this is an add rather than an update */
@@ -158,9 +158,9 @@
 static const ne_propname log_message_prop = { SVN_DAV_PROP_NS_SVN, "log" };
 
 /* perform a deep copy of BASE into POOL, and return the result. */
-static resource_t * dup_resource(resource_t *base, apr_pool_t *pool)
+static resauce_t * dup_resource(resauce_t *base, apr_pool_t *pool)
 {
- resource_t *rsrc = apr_pcalloc(pool, sizeof(*rsrc));
+ resauce_t *rsrc = apr_pcalloc(pool, sizeof(*rsrc));
   rsrc->pool = pool;
   rsrc->revision = base->revision;
   rsrc->url = base->url ?
@@ -229,7 +229,7 @@
 /* Get the version resource URL for RSRC, storing it in
    RSRC->vsn_url. Use POOL for all temporary allocations. */
 static svn_error_t * get_version_url(commit_ctx_t *cc,
- resource_t *rsrc,
+ resauce_t *rsrc,
                                      svn_boolean_t force,
                                      apr_pool_t *pool)
 {
@@ -397,15 +397,15 @@
 
 /* Add a child resource. POOL should be as "temporary" as possible,
    but probably not as far as requiring a new temp pool. */
-static svn_error_t * add_child(resource_t **child,
+static svn_error_t * add_child(resauce_t **child,
                                commit_ctx_t *cc,
- const resource_t *parent,
+ const resauce_t *parent,
                                const char *name,
                                int created,
                                svn_revnum_t revision,
                                apr_pool_t *pool)
 {
- resource_t *rsrc;
+ resauce_t *rsrc;
 
   /* ### todo: This from Yoshiki Hayashi <yoshiki@xemacs.org>:
 
@@ -496,7 +496,7 @@
 
 
 static svn_error_t * checkout_resource(commit_ctx_t *cc,
- resource_t *rsrc,
+ resauce_t *rsrc,
                                        svn_boolean_t allow_404,
                                        const char *token,
                                        apr_pool_t *pool)
@@ -628,7 +628,7 @@
 
 */
 static svn_error_t * do_proppatch(svn_ra_dav__session_t *ras,
- const resource_t *rsrc,
+ const resauce_t *rsrc,
                                   resource_baton_t *rb,
                                   apr_pool_t *pool)
 {
@@ -669,7 +669,7 @@
 {
   commit_ctx_t *cc = edit_baton;
   resource_baton_t *root;
- resource_t *rsrc;
+ resauce_t *rsrc;
 
   /* create the root resource. no wr_url (yet). */
   rsrc = apr_pcalloc(dir_pool, sizeof(*rsrc));
@@ -920,7 +920,7 @@
   int code;
   const char *name = svn_path_basename(path, dir_pool);
   apr_pool_t *workpool = svn_pool_create(dir_pool);
- resource_t *rsrc = NULL;
+ resauce_t *rsrc = NULL;
 
   /* check out the parent resource so that we can create the new collection
      as one of its children. */
@@ -1017,7 +1017,7 @@
   resource_baton_t *child = apr_pcalloc(dir_pool, sizeof(*child));
   const char *name = svn_path_basename(path, dir_pool);
   apr_pool_t *workpool = svn_pool_create(dir_pool);
- resource_t *rsrc = NULL;
+ resauce_t *rsrc = NULL;
 
   child->pool = dir_pool;
   child->cc = parent->cc;
@@ -1084,7 +1084,7 @@
   resource_baton_t *file;
   const char *name = svn_path_basename(path, file_pool);
   apr_pool_t *workpool = svn_pool_create(file_pool);
- resource_t *rsrc = NULL;
+ resauce_t *rsrc = NULL;
 
   /*
   ** To add a new file into the repository, we CHECKOUT the parent
@@ -1232,7 +1232,7 @@
   resource_baton_t *file;
   const char *name = svn_path_basename(path, file_pool);
   apr_pool_t *workpool = svn_pool_create(file_pool);
- resource_t *rsrc = NULL;
+ resauce_t *rsrc = NULL;
 
   file = apr_pcalloc(file_pool, sizeof(*file));
   file->pool = file_pool;
@@ -1459,7 +1459,7 @@
 {
   const svn_string_t *vcc;
   const svn_string_t *baseline_url;
- resource_t baseline_rsrc = { SVN_INVALID_REVNUM };
+ resauce_t baseline_rsrc = { SVN_INVALID_REVNUM };
   ne_proppatch_operation po[2] = { { 0 } };
   int rv;
   svn_stringbuf_t *xml_data;

---------------------------------------------------------------------
To unsubscribe, e-mail: users-unsubscribe@subversion.tigris.org
For additional commands, e-mail: users-help@subversion.tigris.org
Received on Mon Nov 21 10:22:11 2005
@@ -51,7 +51,7 @@
 
 /*
-** resource_t: identify the relevant pieces of a resource on the server
+** resauce_t: identify the relevant pieces of a resource on the server
 **
 ** REVISION is the resource's revision, or SVN_INVALID_REVNUM if it is

This is an archived mail posted to the Subversion Users mailing list.

This site is subject to the Apache Privacy Policy and the Apache Public Forum Archive Policy.